@@ -560,6 +560,29 @@ Arrays are new in Miller 6; the substr function is older.`,
 			binaryFunc: bifs.BIF_truncate,
 		},
 
+		{
+			name:        "leftpad",
+			class:       FUNC_CLASS_STRING,
+			help:        `Left-pads first argument to at most the specified length (second, integer argument) using specified pad value (third, string argument). If the first argument is not a string, it will be stringified first.`,
+			ternaryFunc: bifs.BIF_leftpad,
+			examples: []string{
+				`leftpad("abcdefg", 10 , "*") gives "***abcdefg".`,
+				`leftpad("abcdefg", 10 , "XY") gives "XYabcdefg".`,
+				`leftpad("1234567", 10 , "0") gives "0001234567".`,
+			},
+		},
+		{
+			name:        "rightpad",
+			class:       FUNC_CLASS_STRING,
+			help:        `Right-pads first argument to at most the specified length (second, integer argument) using specified pad value (third, string argument). If the first argument is not a string, it will be stringified first.`,
+			ternaryFunc: bifs.BIF_rightpad,
+			examples: []string{
+				`rightpad("abcdefg", 10 , "*") gives "abcdefg***".`,
+				`rightpad("abcdefg", 10 , "XY") gives "abcdefgXY".`,
+				`rightpad("1234567", 10 , "0") gives "1234567000".`,
+			},
+		},
+
 		{
 			name:  "format",
 			class: FUNC_CLASS_STRING,
